Installation
============

Required dependencies
---------------------

* `Numpy <http://www.numpy.org/>`_
* `Xarray <http://xarray.pydata.org/en/stable/#>`_ (0.13.* or later)
* `Scipy <https://www.scipy.org/>`_
* `rasterio <https://github.com/mapbox/rasterio>`_
* `Nose2 <https://docs.nose2.io/en/latest/>`_
* `json-checker <https://github.com/DKorytkin/json_checker>`_
* `netCDF4 <https://github.com/Unidata/netcdf4-python>`_
* `numba <http://numba.pydata.org/>`_ (0.47.* or later)
* `opencv-python <https://github.com/skvark/opencv-python>`_



Instructions
------------

This package can be install through the following commands:

.. sourcecode:: text

   $ pip install pandora